Module blaxel.core.client.models.preview
========================================

Classes
-------

`Preview(metadata: blaxel.core.client.types.Unset | ForwardRef('PreviewMetadata') = <blaxel.core.client.types.Unset object>, spec: blaxel.core.client.types.Unset | ForwardRef('PreviewSpec') = <blaxel.core.client.types.Unset object>)`
:   Preview of a Resource
    
    Attributes:
        metadata (Union[Unset, PreviewMetadata]): PreviewMetadata
        spec (Union[Unset, PreviewSpec]): Preview of a Resource
    
    Method generated by attrs for class Preview.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `metadata`
    :

    `spec`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :